local json = require("json")
local utils = require("utils")
local utils_device = require("utils_device")
local pl_pretty = require("pl.pretty")
local resty_string = require("resty.string")
local upload = require("resty.upload")
local Set = require("set")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DeviceManage")

if ("POST" == request_method) then
    ngx.req.read_body()
    local args_json = ngx.req.get_body_data()
    -- utils.log_error ( "device 3tuple: "..args_json)
    local args = json.decode(args_json)
    if (nil == args) then
        utils.error_exit(400)
    end

    local all_device_3tuple = {}
    local pk_set = Set:new(utils.get_product_key_list())
    local count_succeed = 0
    for _, device_3tuple in ipairs(args) do
        if (3 == #device_3tuple) then
            local pk = device_3tuple[1]
            local dn = device_3tuple[2]
            local ds = device_3tuple[3]
            if ( (pk ~= "Productkey") and (dn ~= "DeviceName") and (ds ~= "DeviceSecret") ) then
                utils.check_pk(pk);
                utils.check_dn(dn);
                utils.check_ds(ds);
		count_succeed = count_succeed + 1
                table.insert(all_device_3tuple, device_3tuple)
                -- set product key
                Set.add(pk_set, device_3tuple[1])
            end
        else
            utils.error_exit(400, "illegal data format")
        end
    end

    if (#all_device_3tuple == 0) then
        utils.error_exit(400, "illegal data format")
    end

    utils.set_product_key_list(Set.tolist(pk_set))
    utils_device.set_3tuple(json.encode(all_device_3tuple))
    local last_total_quanlity = utils_device.get_3tuple_quanlity()
    utils_device.set_3tuple_quanlity(last_total_quanlity + #all_device_3tuple)
    local res = {}
    res["code"] = 200
    res["message"] = "success"
    res["data"] = count_succeed
    ngx.say(json.encode(res))
    ngx.exit(200)

elseif ("GET" == request_method) then
    ok, msg = utils_device.get_3tuple()
    if (ok) then
        if (nil == msg) then
            msg = "[]"
        end
        res = '{"code": 200, "message": "success", "data": {"List": ' .. msg .. '}}'
        ngx.say(res)
        ngx.exit(200)
        -- utils.error_exit(200, res)
    end

    utils.error_exit(500, "get tuple failed")
end

utils.error_exit(400, "unsupported request method")
