local json = require("json")
local utils = require("utils")
local utils_device = require("utils_device")

local request_method = ngx.var.request_method

utils.check_login()
utils.check_permission("DeviceManage")

if ("GET" == request_method) then
    local args = ngx.req.get_uri_args()
    if (nil == args) then
        utils.error_exit(400, "invalid parameter")
    end

    local driver_name = args["DriverName"]
    local pk = args["ProductKey"]
    local lid = args["DeviceLocalID"]
    local page_size = tonumber(args["PageSize"])
    local cur_page = tonumber(args["CurrentPage"])

    utils.check_page_size(page_size)
    utils.check_current_page(cur_page)

    if (driver_name and "" == string.gsub(driver_name, '%s', "")) then
        driver_name = nil -- treat space characters as empty
    end

    if (pk and "" == string.gsub(pk, '%s', "")) then
        pk = nil -- treat space characters as empty
    end

    if (lid and "" == string.gsub(lid, '%s', "")) then
        lid = nil -- treat space characters as empty
    end

    local res_list = {}
    local total, unauth_list = utils_device.get_unauth_device_list(driver_name, pk, lid, page_size, cur_page)

    local res = {}
    res["TotalNum"] = total
    res["PageSize"] = page_size
    res["CurrentPage"] = cur_page
    res["List"] = unauth_list
    utils.error_exit(200, json.encode(res))
end

utils.error_exit(400, "unsupported request method")
