local json = require("json")
local utils = require("utils")
local const = require("const")
local request_method = ngx.var.request_method

utils.check_login()
_, login_token = utils.check_permission("DeviceManage")

local function check_activeStatus(status)
    
    if not status then
        return nil
    elseif tonumber(status) == 0 then
        return "notActivated"
    elseif tonumber(status) == 1 then
        return "activated"
    else
        utils.error_exit(400, "activeStatus must be [null, 0, 1]")
    end
end

function table_leng(t)
  local leng=0
  for k, v in pairs(t) do
    leng=leng+1
  end
  return leng;
end

local function check_onlineStatus(status)
    
    if not status then
        return nil
    elseif tonumber(status) == 0 then
        return "offline"
    elseif tonumber(status) == 1 then
        return "online"
    else
        utils.error_exit(400, "onlineStatus must be [null, 0, 1]")
    end
end

if "POST" == request_method then
    local utils_header = require("utils_header")
    local params = utils_header.check_public_boby_data()
    local productKey = params["productKey"]
    local activeStatus = check_activeStatus(params["activeStatus"])
    local onlineStatus = check_onlineStatus(params["onlineStatus"])
    local selector = {}
    local device_num = {}
    if (productKey ~= nil) then
        utils.check_pk(productKey)
        selector["productKey"] = productKey
    end
    
    if (activeStatus ~= nil) then
        selector["activation"] = activeStatus 
    end

    if (onlineStatus ~= nil) then
        selector["deviceState"] = onlineStatus 
    end

    local cmd = nil
    if table_leng(selector) == 0 then
        cmd = ""
    else
        cmd = json.encode(selector)
    end

    local ok, msg_raw, err = utils.dbus_call_edge(const.dimu.wkn,
                                        const.dimu.obj,
                                        const.dimu.inf,
                                        "getDeviceList",
                                        cmd)
    if (ok and msg_raw) then
        local ok, msg = pcall(json.decode, msg_raw[1])
        if (ok and 0 == msg["code"]) then
            device_num["deviceCount"] = msg["params"]["devNum"]
        else
            utils.error_exit(500, json.encode("failed to query: "..msg_raw[1]))
        end
    else
        utils.error_exit(500, json.encode("failed to query: "..err))
    end 

    utils.error_exit(200, json.encode(device_num)) 

end
utils.error_exit(400, "unsupported request method")

