/*
 * Copyright (c) 2018 Alibaba Group Holding Ltd.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 /*
 * Function description:
 * This function is used to filter the data reported by the LightSensor device.
 * Report the device data to cloud only when illuminance value is greater than 500 or less than 200.
 */

'use strict';

const leSdk = require('linkedge-core-sdk');
const iotData = new leSdk.IoTData();
var function_invoke_times_g = 0;

module.exports.handler = function (event, context, callback) {
  function_invoke_times_g++;
  console.log(`-- Invocation Time {${function_invoke_times_g}} --`);
  console.log(`-- Receive event: ${event.toString()}`);

  try {
    var illuminance = iotData.getThingPropertyByEvent(event, "MeasuredIlluminance");
    if (illuminance == null) {
      console.log('-- Cannot find required property "MeasuredIlluminance" from event.');
      callback(null);
      return;
    }
  } catch (err) {
    err = new Error(`Parse event failed due to ${err}.`);
    callback(err);
    return;
  }

  console.log(`-- Illuminance value is ${illuminance}.`);
  if (illuminance > 500 || illuminance < 200) {
    console.log(`-- Report data to AliCloud IoT!`);

    var eventObj = JSON.parse(event.toString());
    if (!eventObj.payload || !eventObj.topic) {
      callback(new Error(`Can't find "payload" or "topic" in event.`));
      return;
    }
    const message = {
      topic: eventObj.topic,
      payload: eventObj.payload,
    };
    
    iotData.publish(message, (err, data)=> {
      callback(err);
    });
  } else {
    console.log(`-- Ignore.`);
    callback(null);
  }
};

